==> leoo_junpro-1.0.1.tar.gz: lib/leooimpjunpro/leoomatjunpro/leoomatwaitjunpro.dart <==
import 'dart:async';
import 'dart:core';
import 'dart:math';

import 'package:agora_rtm/agora_rtm.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoodaojunpro/leoomaindaojunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoortmentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoouserentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoouserlistentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooproviderjunpro/leoouserproviderjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostringjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoorechargeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoovideoutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoobuttonwidgetjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoospinwidgetjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leooinfojunpro/leooinfojunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoomatjunpro/leoomatinfojunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:provider/provider.dart';

///Random等待
class LeooMatWaitJunPro extends StatefulWidget {
  static bool leooOpenJunPro = false;
  final bool recommended;

  const LeooMatWaitJunPro(this.recommended, {Key? key}) : super(key: key);

  @override
  _LeooMatchWaitState createState() => _LeooMatchWaitState();
}

class _LeooMatchWaitState extends State<LeooMatWaitJunPro>
    with WidgetsBindingObserver, RouteAware, OnRtmPluginDelegate {
  late Timer timer;
  late String randomTip;
  GlobalKey<LeooButtonWidgetState> buttonKey = GlobalKey();
  bool random = false;
  Random rand = Random();
  List<LeooUserListEntity> allList = [];
  Timer? matchTimer;

  @override
  void initState() {
    super.initState();
    LeooVideoUtilsJunPro.instance.rtmPluginDelegateList.add(this);
    WidgetsBinding.instance?.addObserver(this);
    LeooMatWaitJunPro.leooOpenJunPro = true;
    randomTip = LeooStringJunPro.leooStrRandomTipJunPro[0];
    timer = Timer.periodic(const Duration(seconds: 2), (timer) {
      randomTip = LeooStringJunPro.leooStrRandomTipJunPro[
          rand.nextInt(LeooStringJunPro.leooStrRandomTipJunPro.length)];
    });
    startRandom();
    if (widget.recommended) {
      getList();
    }
  }

  void getList() {
    LeooMainDaoJunPro.leooListRecommendJunPro().then((res) async {
      if (res.result) {
        allList = res.data;
        LeooCodeUtilsJunPro.onSetState(this);
      }
    });
  }

  void startRandom() {
    Future.delayed(const Duration(seconds: 2), () {
      if (random) {
        return;
      }
      random = true;
      goRandomInfo();
    });
  }

  void goRandomInfo() {
    LeooMainDaoJunPro.leooMatchingJunPro().then((res) async {
      random = false;
      if (res.result) {
        if (res.data.result) {
          if (res.data.matchingId != null) {
            checkMatchInfo(res.data.matchedUserId, res.data.matchingId);
          } else {
            matchTimer?.cancel();
            matchTimer = Timer(
                Duration(seconds: LeooAppConfigJunPro.leooMatchWaitTimeJunPro),
                () {
              startRandom();
            });
          }
        } else {
          LeooRechargeUtilsJunPro.instance
              .showRechargeDialog(context, S.of(context).diamondMatchTip,
                  call: true)
              .then((value) {
            if (value != null) {
              startRandom();
            } else {
              Navigator.pop(context);
            }
          });
        }
      } else {
        LeooCommonUtilsJunPro.leooShowErrorToastJunPro(res);
        Navigator.pop(context);
      }
    });
  }

  @override
  void onRtmMessageReceived(LeooRtmEntity rtmEntity) {
    if (rtmEntity.type == 1) {
      matchTimer?.cancel();
      checkMatchInfo(rtmEntity.matchingUserId, rtmEntity.matchingId);
    }
  }

  void checkMatchInfo(int? matchedUserId, int? matchingId) {
    LeooMainDaoJunPro.leooDetailJunPro(matchedUserId).then((resInfo) async {
      if (resInfo.result) {
        LeooMainDaoJunPro.leooFreeVideoJunPro(matchedUserId)
            .then((resVideo) async {
          String? videoUrl;
          if (resVideo.result) {
            videoUrl = resVideo.data.videoUrl;
          }
          showRandomInfo(matchingId, resInfo.data, videoUrl).then((value) {
            if (value != 0) {
              if (value != 4) {
                LeooMainDaoJunPro.leooOperateJunPro(matchingId, value ?? 2);
              }
              startRandom();
            }
          });
        });
      } else {
        LeooCommonUtilsJunPro.leooShowErrorToastJunPro(resInfo);
        Navigator.pop(context);
      }
    });
  }

  Future showRandomInfo(
      int? matchingId, LeooUserEntity infoEntity, String? videoUrl) {
    return LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      return LeooNavigatorUtilsJunPro.leooShowBaseDialogJunPro(
        context,
        name: 'showRandomInfo',
        builder: (BuildContext showContext) {
          return LeooMatInfoJunPro(matchingId, infoEntity, videoUrl: videoUrl);
        },
      );
    });
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        startRandom();
      });
    }
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    Future.delayed(const Duration(milliseconds: 500), () async {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        startRandom();
      });
    });
  }

  @override
  void dispose() {
    LeooVideoUtilsJunPro.instance.rtmPluginDelegateList.remove(this);
    WidgetsBinding.instance?.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    timer.cancel();
    matchTimer?.cancel();
    LeooMatWaitJunPro.leooOpenJunPro = false;
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<LeooUserProviderJunPro>(
        builder: (_, LeooUserProviderJunPro userProvider, __) {
      return Scaffold(
        resizeToAvoidBottomInset: false,
        body: SafeArea(
          maintainBottomViewPadding: true,
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              SizedBox(height: 5.w),
              Row(
                children: <Widget>[
                  SizedBox(width: 4.w),
                  IconButton(
                    iconSize: 40.w,
                    padding: const EdgeInsets.all(0),
                    icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                        LeooIconsJunPro.leooTopBackJunPro,
                        width: 40.w,
                        height: 40.w),
                    onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                      Navigator.pop(context);
                    }),
                  ),
                  Expanded(child: Container()),
                  if (userProvider.userEntity.userType == 0)
                    LeooWidgetUtilsJunPro.leooGetMainCoinsWidgetJunPro(
                        context, userProvider.userEntity.amount, false),
                  SizedBox(width: 15.w),
                ],
              ),
              Hero(
                tag: 'LeooMatWaitJunPro',
                transitionOnUserGestures: true,
                child: Stack(
                  alignment: Alignment.center,
                  children: [
                    LeooCommonUtilsJunPro.leooLottieJunPro(
                      LeooIconsJunPro.leooMatWaitJunPro,
                      width: 1.sw,
                      height: 1.sw,
                    ),
                    LeooSpinWidgetJunPro(
                      seconds: 15,
                      child: Container(
                        width: 120.w,
                        height: 120.w,
                        decoration: ShapeDecoration(
                          shape: CircleBorder(
                            side: BorderSide(
                              color: LeooColorsJunPro.leooAppJunPro,
                              width: 4.w,
                            ),
                          ),
                        ),
                        child: ClipOval(
                          child: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                            userProvider.userEntity.header,
                            width: 120.w,
                            height: 120.w,
                            load: LeooIconsJunPro.leooLoadHeadJunPro,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              SizedBox(height: 20.w),
              Text(S.of(context).matchSearching,
                  style: LeooTextJunPro.leooGetTextStyleAppJunPro(
                      24, FontWeight.bold),
                  textAlign: TextAlign.center),
              SizedBox(height: 5.w),
              Padding(
                padding: EdgeInsets.only(left: 45.w, right: 45.w),
                child: Text(
                  randomTip,
                  style: LeooTextJunPro.leooGetTextStyleHintJunPro(16),
                  textAlign: TextAlign.center,
                ),
              ),
              if (allList.isNotEmpty)
                Expanded(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Padding(
                        padding: EdgeInsets.all(15.w),
                        child: Text(
                          S.of(context).matchGuess,
                          style: LeooTextJunPro.leooGetTextStyleJunPro(
                              16, FontWeight.bold),
                        ),
                      ),
                      SizedBox(
                        height: 50.w,
                        child: ListView.separated(
                            physics: const BouncingScrollPhysics(),
                            scrollDirection: Axis.horizontal,
                            itemCount: allList.length,
                            separatorBuilder:
                                (BuildContext context, int index) {
                              return SizedBox(width: 10.w);
                            },
                            padding: EdgeInsets.only(left: 20.w, right: 20.w),
                            itemBuilder: (BuildContext itemContext, int index) {
                              LeooUserListEntity item = allList[index];
                              return InkWell(
                                child: Stack(
                                  alignment: Alignment.topRight,
                                  children: [
                                    ClipOval(
                                      child: LeooCommonUtilsJunPro
                                          .leooGetLoadWidgetJunPro(
                                        item.header,
                                        width: 50.w,
                                        height: 50.w,
                                        load:
                                            LeooIconsJunPro.leooLoadHeadJunPro,
                                      ),
                                    ),
                                    LeooWidgetUtilsJunPro
                                        .leooGetOnlineTipJunPro(
                                            context, item.onlineStatus ?? 2),
                                  ],
                                ),
                                onTap:
                                    LeooNavigatorUtilsJunPro.leooDebounceJunPro(
                                        () {
                                  Navigator.pop(context);
                                  LeooUserEntity infoEntity = LeooUserEntity(
                                    id: item.userId,
                                    nickname: item.nickname,
                                    header: item.header,
                                  );
                                  LeooNavigatorUtilsJunPro
                                      .leooNavigatorPushJunPro(
                                          context,
                                          LeooInfoJunPro(
                                              item.userId,
                                              infoEntity,
                                              'matchWait${item.userId}'),
                                          'LeooInfoJunPro',
                                          add: true);
                                }),
                              );
                            }),
                      ),
                    ],
                  ),
                ),
            ],
          ),
        ),
      );
    });
  }

  @override
  void onRemoteInvitationCanceled(AgoraRtmRemoteInvitation invite) {}
}

==> leoo_junpro-2.0.0.tar.gz: lib/leooimpjunpro/leoomatjunpro/leoomatwaitjunpro.dart <==
import 'dart:async';
import 'dart:core';
import 'dart:math';

import 'package:agora_rtm/agora_rtm.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoodaojunpro/leoomaindaojunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoortmentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoouserentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoouserlistentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooproviderjunpro/leoouserproviderjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostringjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoorechargeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoovideoutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoobuttonwidgetjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoospinwidgetjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leooinfojunpro/leooinfojunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoomatjunpro/leoomatinfojunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:provider/provider.dart';

///Random等待
class LeooMatWaitJunPro extends StatefulWidget {
  static bool leooOpenJunPro = false;
  final bool recommended;

  const LeooMatWaitJunPro(this.recommended, {Key? key}) : super(key: key);

  @override
  _LeooMatchWaitState createState() => _LeooMatchWaitState();
}

class _LeooMatchWaitState extends State<LeooMatWaitJunPro>
    with WidgetsBindingObserver, RouteAware, OnRtmPluginDelegate {
  late Timer timer;
  late String randomTip;
  GlobalKey<LeooButtonWidgetState> buttonKey = GlobalKey();
  bool random = false;
  Random rand = Random();
  List<LeooUserListEntity> allList = [];
  Timer? matchTimer;

  @override
  void initState() {
    super.initState();
    LeooVideoUtilsJunPro.instance.rtmPluginDelegateList.add(this);
    WidgetsBinding.instance.addObserver(this);
    LeooMatWaitJunPro.leooOpenJunPro = true;
    randomTip = LeooStringJunPro.leooStrRandomTipJunPro[0];
    timer = Timer.periodic(const Duration(seconds: 2), (timer) {
      randomTip = LeooStringJunPro.leooStrRandomTipJunPro[
          rand.nextInt(LeooStringJunPro.leooStrRandomTipJunPro.length)];
    });
    startRandom();
    if (widget.recommended) {
      getList();
    }
  }

  void getList() {
    LeooMainDaoJunPro.leooListRecommendJunPro().then((res) async {
      if (res.result) {
        allList = res.data;
        LeooCodeUtilsJunPro.onSetState(this);
      }
    });
  }

  void startRandom() {
    Future.delayed(const Duration(seconds: 2), () {
      if (random) {
        return;
      }
      random = true;
      goRandomInfo();
    });
  }

  void goRandomInfo() {
    LeooMainDaoJunPro.leooMatchingJunPro().then((res) async {
      random = false;
      if (res.result) {
        if (res.data.result) {
          if (res.data.matchingId != null) {
            checkMatchInfo(res.data.matchedUserId, res.data.matchingId);
          } else {
            matchTimer?.cancel();
            matchTimer = Timer(
                Duration(seconds: LeooAppConfigJunPro.leooMatchWaitTimeJunPro),
                () {
              startRandom();
            });
          }
        } else {
          LeooRechargeUtilsJunPro.instance
              .showRechargeDialog(context, S.of(context).diamondMatchTip,
                  call: true)
              .then((value) {
            if (value != null) {
              startRandom();
            } else {
              Navigator.pop(context);
            }
          });
        }
      } else {
        LeooCommonUtilsJunPro.leooShowErrorToastJunPro(res);
        Navigator.pop(context);
      }
    });
  }

  @override
  void onRtmMessageReceived(LeooRtmEntity rtmEntity) {
    if (rtmEntity.type == 1) {
      matchTimer?.cancel();
      checkMatchInfo(rtmEntity.matchingUserId, rtmEntity.matchingId);
    }
  }

  void checkMatchInfo(int? matchedUserId, int? matchingId) {
    LeooMainDaoJunPro.leooDetailJunPro(matchedUserId).then((resInfo) async {
      if (resInfo.result) {
        LeooMainDaoJunPro.leooFreeVideoJunPro(matchedUserId)
            .then((resVideo) async {
          String? videoUrl;
          if (resVideo.result) {
            videoUrl = resVideo.data.videoUrl;
          }
          showRandomInfo(matchingId, resInfo.data, videoUrl).then((value) {
            if (value != 0) {
              if (value != 4) {
                LeooMainDaoJunPro.leooOperateJunPro(matchingId, value ?? 2);
              }
              startRandom();
            }
          });
        });
      } else {
        LeooCommonUtilsJunPro.leooShowErrorToastJunPro(resInfo);
        Navigator.pop(context);
      }
    });
  }

  Future showRandomInfo(
      int? matchingId, LeooUserEntity infoEntity, String? videoUrl) {
    return LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      return LeooNavigatorUtilsJunPro.leooShowBaseDialogJunPro(
        context,
        name: 'showRandomInfo',
        builder: (BuildContext showContext) {
          return LeooMatInfoJunPro(matchingId, infoEntity, videoUrl: videoUrl);
        },
      );
    });
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        startRandom();
      });
    }
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    Future.delayed(const Duration(milliseconds: 500), () async {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        startRandom();
      });
    });
  }

  @override
  void dispose() {
    LeooVideoUtilsJunPro.instance.rtmPluginDelegateList.remove(this);
    WidgetsBinding.instance.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    timer.cancel();
    matchTimer?.cancel();
    LeooMatWaitJunPro.leooOpenJunPro = false;
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<LeooUserProviderJunPro>(
        builder: (_, LeooUserProviderJunPro userProvider, __) {
      return Scaffold(
        resizeToAvoidBottomInset: false,
        body: SafeArea(
          maintainBottomViewPadding: true,
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              SizedBox(height: 5.w),
              Row(
                children: <Widget>[
                  SizedBox(width: 4.w),
                  IconButton(
                    iconSize: 40.w,
                    padding: const EdgeInsets.all(0),
                    icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                        LeooIconsJunPro.leooTopBackJunPro,
                        width: 40.w,
                        height: 40.w),
                    onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                      Navigator.pop(context);
                    }),
                  ),
                  Expanded(child: Container()),
                  if (userProvider.userEntity.userType == 0)
                    LeooWidgetUtilsJunPro.leooGetMainCoinsWidgetJunPro(
                        context, userProvider.userEntity.amount, false),
                  SizedBox(width: 15.w),
                ],
              ),
              Hero(
                tag: 'LeooMatWaitJunPro',
                transitionOnUserGestures: true,
                child: Stack(
                  alignment: Alignment.center,
                  children: [
                    LeooCommonUtilsJunPro.leooLottieJunPro(
                      LeooIconsJunPro.leooMatWaitJunPro,
                      width: 1.sw,
                      height: 1.sw,
                    ),
                    LeooSpinWidgetJunPro(
                      seconds: 15,
                      child: Container(
                        width: 120.w,
                        height: 120.w,
                        decoration: ShapeDecoration(
                          shape: CircleBorder(
                            side: BorderSide(
                              color: LeooColorsJunPro.leooAppJunPro,
                              width: 4.w,
                            ),
                          ),
                        ),
                        child: ClipOval(
                          child: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                            userProvider.userEntity.header,
                            width: 120.w,
                            height: 120.w,
                            load: LeooIconsJunPro.leooLoadHeadJunPro,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              SizedBox(height: 20.w),
              Text(S.of(context).matchSearching,
                  style: LeooTextJunPro.leooGetTextStyleAppJunPro(
                      24, FontWeight.bold),
                  textAlign: TextAlign.center),
              SizedBox(height: 5.w),
              Padding(
                padding: EdgeInsets.only(left: 45.w, right: 45.w),
                child: Text(
                  randomTip,
                  style: LeooTextJunPro.leooGetTextStyleHintJunPro(16),
                  textAlign: TextAlign.center,
                ),
              ),
              if (allList.isNotEmpty)
                Expanded(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Padding(
                        padding: EdgeInsets.all(15.w),
                        child: Text(
                          S.of(context).matchGuess,
                          style: LeooTextJunPro.leooGetTextStyleJunPro(
                              16, FontWeight.bold),
                        ),
                      ),
                      SizedBox(
                        height: 50.w,
                        child: ListView.separated(
                            physics: const BouncingScrollPhysics(),
                            scrollDirection: Axis.horizontal,
                            itemCount: allList.length,
                            separatorBuilder:
                                (BuildContext context, int index) {
                              return SizedBox(width: 10.w);
                            },
                            padding: EdgeInsets.only(left: 20.w, right: 20.w),
                            itemBuilder: (BuildContext itemContext, int index) {
                              LeooUserListEntity item = allList[index];
                              return InkWell(
                                child: Stack(
                                  alignment: Alignment.topRight,
                                  children: [
                                    ClipOval(
                                      child: LeooCommonUtilsJunPro
                                          .leooGetLoadWidgetJunPro(
                                        item.header,
                                        width: 50.w,
                                        height: 50.w,
                                        load:
                                            LeooIconsJunPro.leooLoadHeadJunPro,
                                      ),
                                    ),
                                    LeooWidgetUtilsJunPro
                                        .leooGetOnlineTipJunPro(
                                            context, item.onlineStatus ?? 2),
                                  ],
                                ),
                                onTap:
                                    LeooNavigatorUtilsJunPro.leooDebounceJunPro(
                                        () {
                                  Navigator.pop(context);
                                  LeooUserEntity infoEntity = LeooUserEntity(
                                    id: item.userId,
                                    nickname: item.nickname,
                                    header: item.header,
                                  );
                                  LeooNavigatorUtilsJunPro
                                      .leooNavigatorPushJunPro(
                                          context,
                                          LeooInfoJunPro(
                                              item.userId,
                                              infoEntity,
                                              'matchWait${item.userId}'),
                                          'LeooInfoJunPro',
                                          add: true);
                                }),
                              );
                            }),
                      ),
                    ],
                  ),
                ),
            ],
          ),
        ),
      );
    });
  }

  @override
  void onRemoteInvitationCanceled(AgoraRtmRemoteInvitation invite) {}
}
